@@ -89,7 +89,7 @@ def preprocess_orcaflex(job):
     else:
         job.options = OrcaFlexJobOptions()
     job.warnings = job.add_item_data(
-        "warnings", data={"warning_text": []}, meta={"_class": "orcaflex.warnings"},
+        "warnings", data={"warning_text": []}, meta={"_class": "orcaflex.warnings"}
     )
     # job.state = job.add_item_data("state", data={"state": "Pre-processing"})
     job.entity["meta"]["state"] = OrcaFlexJobState(state="preprocessing").__dict__
