@@ -179,7 +179,7 @@ class OrcaFlexBatchManager:
         source: BaseSource,
         job_options: data_models.OrcaFlexJobOptions = ORCA_FLEX_JOB_OPTIONS,
         required_results: Union[
-            PathLike, Sequence[Union[data_models.TimeHistory, data_models.RangeGraph]],
+            PathLike, Sequence[Union[data_models.TimeHistory, data_models.RangeGraph]]
         ] = (),
         model_views: Sequence[data_models.ModelView] = (),
         load_case_info: data_models.LoadCaseInfo = LOAD_CASE_INFO,
@@ -284,7 +284,7 @@ class OrcaFlexBatch:
 
         # make dicts with data and meta
         opts = dict(
-            data=job["job_options"].__dict__, meta={"_class": "orcaflex.job.options"},
+            data=job["job_options"].__dict__, meta={"_class": "orcaflex.job.options"}
         )
 
         progress = dict(
@@ -333,9 +333,7 @@ class OrcaFlexBatch:
                     list(result_items.values())
                 )  # add items
                 result_items = dict(
-                    zip(
-                        result_items.keys(), [r["guid"] for r in many_results["items"]],
-                    )
+                    zip(result_items.keys(), [r["guid"] for r in many_results["items"]])
                 )  # re-pack
                 # results is a mapping of result name to guid of item
                 job_items["results"] = dict(
@@ -375,7 +373,9 @@ class OrcaFlexBatch:
         if existing_item is not None:
             job_items_zipped[
                 "data_file"
-            ] = existing_item  # the existing item didn't need to be added so we add it here
+            ] = (
+                existing_item
+            )  # the existing item didn't need to be added so we add it here
         if self.verbose:  # print
             print(f"added {case_name}")
         self.session.log.info(f"created {case_name}")
