@@ -51,6 +51,8 @@ class OrcaFlexJobOptions:
     :param max_search_attempts [int]: number or attempts at static search (default = 10)
     :param max_wait [int]: the longest to wait before trying to
         (default = 60)
+    :param update_interval [int]: the number of seconds to wait between updating on
+        model progress (default=5)
     """
 
     time_to_wait: int = 0
@@ -60,6 +62,7 @@ class OrcaFlexJobOptions:
     licence_attempts: int = 3600
     max_search_attempts: int = 10
     max_wait: int = 60
+    update_interval: int = 5
 
 
 @dataclass
@@ -86,7 +89,7 @@ class BatchOptions:
         completion (default=30)
     :param summarise_results[bool]: should we create a results summary automatically
         (default=True)
-    :param build_threads[int]: threads to use to build the batch(default=50)
+    :param build_threads[int]: threads to use to build the batch(default=10)
     :param send_sim_to [list]: queues to send sims to when ``SimBot`` is finished
     :param send_batch_to [list]: queues to send batches to when ``BatchBot`` is finished
     """
@@ -95,7 +98,7 @@ class BatchOptions:
     sim_queue: str
     wait_between_completion_checks: int = 30
     summarise_results: bool = True
-    build_threads: int = 50
+    build_threads: int = 10
     send_sim_to: Sequence = field(default_factory=lambda: [])
     send_batch_to: Sequence = field(default_factory=lambda: [])
 
