@@ -18,14 +18,15 @@ Smart statics gives users the ability to define what they would try in the model
 
 It does this by calling `solved_model` which is documented below.
 """
-import json
 import collections
+import json
 from itertools import cycle
 from logging import getLogger
+from pprint import pformat
 from typing import Sequence, Union, Mapping
 
-from OrcFxAPI import stStaticsFailed, Model, DLLError
 import numpy as np
+from OrcFxAPI import stStaticsFailed, Model, DLLError
 
 from qalx_orcaflex.helpers import get_tags
 
@@ -62,7 +63,7 @@ def gather_search_criteria(model: Model) -> Sequence[Union[Mapping, None]]:
                 search_sequence.insert(int(sequence_number.split("__")[-1]), None)
             else:
                 search_sequence.insert(
-                    int(sequence_number.split("__")[-1]), json.loads(object_filter),
+                    int(sequence_number.split("__")[-1]), json.loads(object_filter)
                 )
     return search, search_sequence
 
@@ -80,6 +81,7 @@ def apply_absolute_adjustment(obj, data_name, index, initial_value, adjustment):
     value = np.random.uniform(min, max)
     logger.info(f"Setting {data_name}[{index}] to {value}")
     obj.SetData(data_name, index, value)
+    return data_name, index, value
 
 
 def apply_nudge(obj, data_name, index, adjustment):
@@ -89,6 +91,7 @@ def apply_nudge(obj, data_name, index, adjustment):
     value = last_value + adjustment["distance"]
     logger.info(f"Setting {data_name}[{index}] to {value}")
     obj.SetData(data_name, index, value)
+    return data_name, index, value
 
 
 def apply_choice(obj, data_name, index, choices):
@@ -98,6 +101,7 @@ def apply_choice(obj, data_name, index, choices):
     value = np.random.choice(choices)
     logger.info(f"Setting {data_name}[{index}] to {value}")
     obj.SetData(data_name, index, value)
+    return data_name, index, value
 
 
 def apply_cycle_choices(obj, data_name, index, choice_cycle):
@@ -108,6 +112,7 @@ def apply_cycle_choices(obj, data_name, index, choice_cycle):
     value = next(choice_cycle)
     logger.info(f"Setting {data_name}[{index}] to {value}")
     obj.SetData(data_name, index, value)
+    return data_name, index, value
 
 
 def apply_all_adjustments(model, search, cycles, object_filter=None):
@@ -121,7 +126,7 @@ def apply_all_adjustments(model, search, cycles, object_filter=None):
         object_filter = {k: [] for k in search.keys()}
     for obj_name in object_filter:
         adjustments = search[obj_name]
-        if object_filter[obj_name] == []:
+        if not object_filter[obj_name]:
             data_names = [n for (n, i) in adjustments.keys()]
         else:
             data_names = object_filter[obj_name]
@@ -133,27 +138,27 @@ def apply_all_adjustments(model, search, cycles, object_filter=None):
             adjustment = adjustment_info["adjustment"]
             initial_value = adjustment_info["initial_value"]
             if adjustment["type"] == "absolute":
-                apply_absolute_adjustment(
+                setting = apply_absolute_adjustment(
                     obj_to_adjust, data_name, index, initial_value, adjustment
                 )
             elif adjustment["type"] == "nudge":
-                apply_nudge(obj_to_adjust, data_name, index, adjustment)
+                setting = apply_nudge(obj_to_adjust, data_name, index, adjustment)
             elif adjustment["type"] == "choice":
-                apply_choice(
-                    obj_to_adjust,
-                    data_name,
-                    index,
-                    np.random.choice(adjustment["choices"]),
+                setting = apply_choice(
+                    obj_to_adjust, data_name, index, adjustment["choices"]
                 )
             elif adjustment["type"] == "cycle":
                 if (obj_name, data_name, index) not in cycles:
                     cycles[(obj_name, data_name, index)] = cycle(adjustment["choices"])
-                apply_cycle_choices(
+                setting = apply_cycle_choices(
                     obj_to_adjust,
                     data_name,
                     index,
                     cycles[(obj_name, data_name, index)],
                 )
+            model.general.Comments += (
+                f"\n{setting[0]}[{setting[1]}] set to " f"{setting[2]}"
+            )
 
 
 def reset_model(model, search):
@@ -180,9 +185,11 @@ def perform_search(model, search, max_attempts, object_filter=None):
     """
     attempts = 0
     cycles = {}
+    model.general.Comments += f"\n***\nSMART STATICS with {pformat(dict(search))}\n***"
     while attempts < max_attempts:
-        apply_all_adjustments(model, search, cycles, object_filter)
         attempts += 1
+        model.general.Comments += f"\n---\nSMART STATICS ATTEMPT {attempts}:"
+        apply_all_adjustments(model, search, cycles, object_filter)
         try:
             model.CalculateStatics()
             return model, True
